REM File Name: 	DEMOGSX.BAS
REM
REM Purpose:	Demonstration program for CBASIC Compiler
REM		interfacing to GSX.
REM
REM		Declares five GSX parameter arrays for:
REM		control, integer in, points in, integer out, points out
REM
REM Calls:	GSX (VARPTR (ptsout%), VARPTR (intout%),
REM		     VARPTR (ptsin%),  VARPTR (intin%),
REM		     VARPTR (contrl%) )
REM
REM To build:	GSX-80:			GSX-86:
REM		CB80 DEMOGSX		CB86 DEMOGSX
REM		LK80 DEMOGSX,GSXCB8O	LINK86 DEMOGSX,GSXCB86
REM
REM History:	Oct. 06, 1983  rhk

DIM contrl% (9), intin% (44), ptsin% (71), intout% (44), ptsout% (39)
DIM paramadr% (4)

DEF GSX (ptsout.adr%, intout.adr%, \
	 ptsin.adr%,  intin.adr%,  \
	 cntrl.adr%) EXTERNAL
	REM Setup for GDOS calls
FEND

DEF bar (x1%, y1%, x2%, y2%)
	REM Use General Drawing BAR primitive
	contrl% (0) = 11
	contrl% (1) = 2
	contrl% (3) = 0
	contrl% (5) = 1
	ptsin%  (0) = x1%
	ptsin%  (1) = y1%
	ptsin%  (2) = x2%
	ptsin%  (3) = y2%
	CALL GSX (paramadr% (4), paramadr% (3), \
		  paramadr% (2), paramadr% (1), \
		  paramadr% (0))
	RETURN
FEND

DEF set.attrib (fid%, inx%)
	contrl% (0) = fid%
	contrl% (1) = 0
	contrl% (2) = 1
	intin%  (0) = inx%
	CALL GSX (paramadr% (4), paramadr% (3), \
		  paramadr% (2), paramadr% (1), \
		  paramadr% (0))
	RETURN
FEND

DEF drawbar (x%, wide%)
	FOR i% = 1 TO 6
	    x1% = x% : x2% = x% + wide%
	    y1% = x1% : y2% = x2%
	    CALL set.attrib (24, i%)
	    CALL bar (x1%, y1%, x2%, y2%)
	    x% = x% + (wide% / 2)
	NEXT i%
	RETURN
FEND

DEF doline (x1%, y1%, x2%, y2%)
	contrl% (0) = 6
	contrl% (1) = 2
	ptsin%  (0) = x1%
	ptsin%  (1) = y1%
	ptsin%  (2) = x2%
	ptsin%  (3) = y2%
	CALL GSX (paramadr% (4), paramadr% (3), \
		  paramadr% (2), paramadr% (1), \
		  paramadr% (0))
	RETURN
FEND

DEF drawfram (x1%, y1%, x2%, y2%)
	contrl% (0) = 6
	contrl% (1) = 5
	ptsin%  (0) = x1% : ptsin% (6) = x1% : ptsin% (8) = x1%
	ptsin%  (1) = y1% : ptsin% (3) = y1% : ptsin% (9) = y1%
	ptsin%  (2) = x2% : ptsin% (4) = x2%
	ptsin%  (5) = y2% : ptsin% (7) = y2%
	CALL GSX (paramadr% (4), paramadr% (3), \
		  paramadr% (2), paramadr% (1), \
		  paramadr% (0))
	RETURN
FEND

DEF gclear
	REM Clear the Display surface
	contrl% (0) = 3
	contrl% (1) = 0
	CALL GSX (paramadr% (4), paramadr% (3), \
		  paramadr% (2), paramadr% (1), \
		  paramadr% (0))
	RETURN
FEND

DEF gclose
	contrl% (0) = 2
	contrl% (1) = 0
	CALL GSX (paramadr% (4), paramadr% (3), \
		  paramadr% (2), paramadr% (1), \
		  paramadr% (0))
	RETURN
FEND

DEF gopen
	contrl% (0) = 1
	contrl% (1) = 0
	contrl% (2) = 10
	intin%  (0) = wid%
	intin%  (1) = 1 : intin% (2) = 1 : intin% (3) = 1
	intin%  (4) = 1 : intin% (5) = 1 : intin% (6) = 1
	intin%  (7) = 1 : intin% (8) = 1 : intin% (9) = 1
	CALL GSX (paramadr% (4), paramadr% (3), \
		  paramadr% (2), paramadr% (1), \
		  paramadr% (0))
	RETURN
FEND

DEF ginit
	PRINT "Which output device:"
	PRINT " 1: CRT"
	PRINT "11: Plotter"
	PRINT "21: Printer"
	PRINT
	INPUT wid%
	PRINT "Open workstation #"; wid%
	RETURN
FEND

REM Main Program

REM Setup PARAMADR with the Addresses of the GSX Parameter Arrays.

	paramadr% (0) = VARPTR (contrl% (0) )
	paramadr% (1) = VARPTR (intin%  (0) )
	paramadr% (2) = VARPTR (ptsin%  (0) )
	paramadr% (3) = VARPTR (intout% (0) )
	paramadr% (4) = VARPTR (ptsout% (0) )

	xmin% = 0
	xmax% = 32767
	ymin% = 0
	ymax = 32767

	CALL ginit
	CALL gopen
	CALL drawfram (xmin%, ymin%, xmax%, ymax%)
	CALL doline (xmin%, ymin%, xmax%, ymax%)
	CALL set.attrib (23, 2)
	CALL drawbar (1200, 1200)
	CALL set.attrib (23, 3)
	CALL drawbar (21968, 1200)
	i% = CONCHAR%
	CALL gclose
	STOP
END
